@@ -10,8 +10,9 @@ pub enum CredentialsError {
     ConfigMissingAccessKeyId,
     #[error("Missing aws_access_key_id section in config")]
     ConfigMissingSecretKey,
-    #[error("Neither {0}, nor {1} exists in the environment",)]
+    #[error("Neither {0}, nor {1} exists in the environment")]
     MissingEnvVar(String, String),
+    #[cfg(feature = "http-credentials")]
     #[error("attohttpc: {0}")]
     Atto(#[from] attohttpc::Error),
     #[error("ini: {0}")]
@@ -25,5 +26,5 @@ pub enum CredentialsError {
     #[error("env var: {0}")]
     Env(#[from] std::env::VarError),
     #[error("Invalid home dir")]
-    HomeDir
-}
\ No newline at end of file
+    HomeDir,
+}
